@@ -2,7 +2,7 @@
 #
 # iTunes Connect client interface
 #
-# Copyright 2008 Brandon Fosdick <bfoz@bfoz.net> (BSD License)
+# Copyright 2008-2009 Brandon Fosdick <bfoz@bfoz.net> (BSD License)
 #
 # $Id: iTunesConnect.pm,v 1.12 2009/01/22 05:23:57 bfoz Exp $
 
@@ -12,7 +12,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION = sprintf("%d.%03d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
+$VERSION = "1.14";
 
 use LWP;
 use HTML::Form;
@@ -38,6 +38,9 @@ sub new
 
     $self->{ua} = LWP::UserAgent->new(%options);
     $self->{ua}->cookie_jar({});
+    # Allow POST requests to be redirected because some of the international
+    #  iTC mirrors redirect various requests
+    push @{ $self->{ua}->requests_redirectable}, 'POST';
 
     return $self;
 }
@@ -120,7 +123,7 @@ sub daily_sales_summary_dates
     my $form = $s->daily_sales_summary_form();
     return undef unless $form;
 # Pull the available dates out of the form's select input
-    my $input = $form->find_input('9.11.1', 'option');
+    my $input = $form->find_input('#dayorweekdropdown', 'option');
     return undef unless $input;
 # Sort and return the dates
     sort { $b cmp $a } $input->possible_values;
@@ -143,10 +146,11 @@ sub daily_sales_summary
 
 # Get an HTML::Form object for the Sales/Trends Reports Daily Summary page
     my $form = $s->daily_sales_summary_form();
+    return undef unless $form;
 # Submit the form to get the latest daily summary
-    $form->value('9.7', 'Summary');
-    $form->value('9.9', 'Daily');
-    $form->value('9.11.1', $date);
+    $form->value('#selReportType', 'Summary');
+    $form->value('#selDateType', 'Daily');
+    $form->value('#dayorweekdropdown', $date);
     $form->value('hiddenDayOrWeekSelection', $date);
     $form->value('hiddenSubmitTypeName', 'Download');
     $form->value('download', 'Download');
@@ -176,9 +180,11 @@ sub financial_report_list
 
 # Get the Items/Page form and set to display the max number of reports
     my @forms = HTML::Form->parse($r);
-    @forms = grep $_->attr('name') eq 'f_0_0_5_1_5_1_1_2_9', @forms;
-    return undef unless @forms;
+    @forms = grep $_->find_input('itemsPerPage', 'text'), @forms;
     my $form = shift @forms;
+    return undef unless $form;
+
+    # Parse the input's label to find the highest value that it can be set to
     $r->as_string =~ /items\/page \(max (\d+)\)/;
     $form->value('itemsPerPage', $1);
     $r = $s->{ua}->request($form->click);
@@ -318,10 +324,11 @@ sub monthly_free_summary
 
 # Get an HTML::Form object for the Sales/Trends Reports Daily Summary page
     my $form = $s->monthly_free_summary_form();
+    return undef unless $form;
 # Submit the form to get the latest weekly summary
-    $form->value('9.7', 'Summary');
-    $form->value('9.9', 'Monthly Free');
-    $form->value('9.14.1', $month);
+    $form->value('#selReportType', 'Summary');
+    $form->value('#selDateType', 'Monthly Free');
+    $form->value('#dayorweekdropdown', $month);
     $form->value('hiddenDayOrWeekSelection', $month);
     $form->value('hiddenSubmitTypeName', 'Download');
     $form->value('download', 'Download');
@@ -348,7 +355,7 @@ sub weekly_sales_summary_dates
     my $form = $s->weekly_sales_summary_form();
     return undef unless $form;
 # Pull the available date ranges out of the form's select input
-    my $input = $form->find_input('9.13.1', 'option');
+    my $input = $form->find_input('#dayorweekdropdown', 'option');
     return undef unless $input;
 # Parse the strings into an array of hash references
     my @dates;
@@ -375,10 +382,11 @@ sub weekly_sales_summary
 
 # Get an HTML::Form object for the Sales/Trends Reports Daily Summary page
     my $form = $s->weekly_sales_summary_form();
+    return undef unless $form;
 # Submit the form to get the latest weekly summary
-    $form->value('9.7', 'Summary');
-    $form->value('9.9', 'Weekly');
-    $form->value('9.13.1', $week);
+    $form->value('#selReportType', 'Summary');
+    $form->value('#selDateType', 'Weekly');
+    $form->value('#dayorweekdropdown', $week);
     $form->value('hiddenDayOrWeekSelection', $week);
     $form->value('hiddenSubmitTypeName', 'Download');
     $form->value('download', 'Download');
@@ -419,8 +427,8 @@ sub daily_sales_summary_form
 #  and submit it to get a list of available Daily Summary dates.
         my $form = $s->sales_form();
         return undef unless $form;
-        $form->value('9.7', 'Summary');
-        $form->value('9.9', 'Daily');
+        $form->value('#selReportType', 'Summary');
+        $form->value('#selDateType', 'Daily');
         $form->value('hiddenSubmitTypeName', 'ShowDropDown');
         my $r = $s->{ua}->request($form->click('download'));
         $s->{daily_summary_sales_response} = $r;
@@ -446,8 +454,8 @@ sub monthly_free_summary_form
 #  and submit it to get a list of available Monthly Summary dates.
         my $form = $s->sales_form();
         return undef unless $form;
-        $form->value('9.7', 'Summary');
-        $form->value('9.9', 'Monthly Free');
+        $form->value('#selReportType', 'Summary');
+        $form->value('#selDateType', 'Monthly Free');
         $form->value('hiddenSubmitTypeName', 'ShowDropDown');
         my $r = $s->{ua}->request($form->click('download'));
         $s->{monthly_summary_free_response} = $r;
@@ -473,8 +481,8 @@ sub weekly_sales_summary_form
 #  and submit it to get a list of available Weekly Summary dates.
         my $form = $s->sales_form();
         return undef unless $form;
-        $form->value('9.7', 'Summary');
-        $form->value('9.9', 'Weekly');
+        $form->value('#selReportType', 'Summary');
+        $form->value('#selDateType', 'Weekly');
         $form->value('hiddenSubmitTypeName', 'ShowDropDown');
         my $r = $s->{ua}->request($form->click('download'));
         $s->{weekly_summary_sales_response} = $r;
@@ -716,7 +724,7 @@ Brandon Fosdick, E<lt>bfoz@bfoz.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Brandon Fosdick <bfoz@bfoz.net>
+Copyright 2008-2009 Brandon Fosdick <bfoz@bfoz.net>
 
 This software is provided under the terms of the BSD License.
 
